@@ -5,9 +5,9 @@ model_list <- readRDS("data/civis_ml_models.rds")
 is_classif <- sapply(model_list, function(m) is(m, "civis_ml_classifier"))
 is_noval <- sapply(model_list, function(m) is.null(m$metrics))
 
-job_ids <- lapply(model_list, function(x) purrr::pluck(x, "job", "id"))
-run_ids <- lapply(model_list, function(x) purrr::pluck(x, "run", "id"))
-id_regex <- purrr:::map2(paste0("(", job_ids, ")*"), paste0("(", run_ids, ")"), paste)
+job_ids <- lapply(model_list, function(x) x[["job"]][["id"]])
+run_ids <- lapply(model_list, function(x) x[["run"]][["id"]])
+id_regex <- paste(paste0("(", job_ids, ")*"), paste0("(", run_ids, ")"))
 class_algo <- sapply(model_list[is_classif], function(x) x$model_info$model$model)
 reg_algo <- sapply(model_list[!is_classif], function(x) x$model_info$model$model)
 
@@ -18,7 +18,7 @@ no_coef_mods <- model_list[!(model_list %in% coef_mods)]
 
 
 str_detect_multiple <- function(string, pattern) {
-  mapply(function(string, pattern) stringr::str_detect(string, pattern),
+  mapply(function(string, pattern) grepl(pattern, string),
          string = string, pattern = pattern)
 }
 
@@ -26,10 +26,10 @@ str_detect_multiple <- function(string, pattern) {
 test_that("print.civis_ml_classifier works", {
   class_msg <- lapply(model_list[is_classif], function(x) utils::capture.output(x))
 
-  first_row <- lapply(class_msg, purrr::pluck, 1)
-  expect_true(all(stringr::str_detect(first_row, class_algo)))
+  first_row <- lapply(class_msg, function(x) x[[1]])
+  mapply(expect_match, first_row, class_algo)
 
-  third_row <- lapply(class_msg, purrr::pluck, 3)
+  third_row <- lapply(class_msg, function(x) x[[3]])
   expect_true(all(str_detect_multiple(third_row, id_regex[is_classif])))
 })
 
@@ -37,22 +37,23 @@ test_that("print.civis_ml_regressor works", {
   reg_msg <- lapply(model_list[!is_classif], function(x) utils::capture.output(x))
   n_models <- length(reg_msg)
 
-  first_row <- lapply(reg_msg, purrr::pluck, 1)
-  expect_true(all(stringr::str_detect(first_row, reg_algo)))
+  first_row <- lapply(reg_msg, function(x) x[[1]])
+  mapply(expect_match, first_row, reg_algo)
 
-  third_row <- lapply(reg_msg, purrr::pluck, 3)
+  third_row <- lapply(reg_msg, function(x) x[[3]])
   expect_true(all(str_detect_multiple(third_row, id_regex[!is_classif])))
 
-  expect_true(all(stringr::str_detect(reg_msg[1:(n_models - 1)], "(MAD)*(RMSE)*(R-squared)")))
-  expect_true(all(stringr::str_detect(reg_msg[1:(n_models - 1)], c("weight"))))
-  expect_true(all(stringr::str_detect(reg_msg[n_models - 1], c("(weight)*(Time)"))))
+  reg_msg <- lapply(reg_msg, paste0, collapse = '')
+  lapply(reg_msg[1:(n_models - 1)], expect_match, "(MAD)*(RMSE)*(R-squared)")
+  lapply(reg_msg[1:(n_models - 1)], expect_match, "weight")
+  lapply(reg_msg[n_models - 1], expect_match, c("(weight)*(Time)"))
 })
 
 test_that("print.civis_ml digits works", {
   m <- model_list[!is_classif][[1]]
   d_str <- capture.output(print(m, digits = 2))[6:8]
-  nums <- lapply(stringr::str_split(d_str, " "), tail, 1)
-  dec <- lapply(purrr::flatten(lapply(nums, stringr::str_split, "\\.")), tail, 1)
+  nums <- lapply(strsplit(d_str, " "), tail, 1)
+  dec <- lapply(sapply(nums, strsplit, "\\."), tail, 1)
   expect_equal(sapply(dec, nchar), rep(2, 3))
 })
 
